@@ -1,6 +1,6 @@
 package Enbld::Definition::Rakudostar;
 
-use 5.012;
+use strict;
 use warnings;
 
 use version;
@@ -19,10 +19,9 @@ sub initialize {
     $self->{defined}{VersionForm}  = '\d{4}\.\d{2}';
     $self->{defined}{DownloadSite} = 'http://rakudo.org/downloads/star/';
 
+    $self->{defined}{TestAction}   = 'rakudo-test';
+
     $self->{defined}{CommandConfigure} = 'perl Configure.pl --gen-parrot';
-    $self->{defined}{CommandMake}      = 'make';
-    $self->{defined}{CommandTest}      = 'make rakudo-test';
-    $self->{defined}{CommandInstall}   = 'make install';
 
     return $self;
 }
