@@ -27,10 +27,7 @@ enbld 'mydevenv' => build {
 
     target 'perl' => define {
         version 'latest';
-        modules {
-            'App::cpanminus' => 0,
-            'Devel::Cover' => 0,
-        };
+        modules 'cpanfile';
     };
 
     target 'pkgconfig' => define {
